<?php
declare(strict_types=1);

namespace App\Form\Type;

use App\Entity\QRCode\QRCodeMoney;
use App\Service\CurrencyListerInterface;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class QRCodeMoneyType extends AbstractType
{
    private readonly CurrencyListerInterface $currencyLister;

    public function __construct(CurrencyListerInterface $currencyLister) {
        $this->currencyLister = $currencyLister;
    }

    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('amount', NumberType::class)
            ->add('currency', ChoiceType::class, [
                'choices' => array_combine(
                    iterator_to_array($this->currencyLister->getCurrencies()),
                    iterator_to_array($this->currencyLister->getCurrencies())
                )
            ]);
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => QRCodeMoney::class,
        ]);
    }
}
